==> nextcloud-app-contacts-8.3.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/contacts/l10n/mn.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "Дэлгэрэнгүй",
    "All contacts" : "Бүх харилцагчид",
    "Contacts" : "Харилцагчид",
    "Copy to full name" : "Бүтэн нэр хуулах",
    "General" : "Ерөнхий",
    "Rename" : "Нэр солих",
    "Delete" : "Устгах",
    "Copied" : "Хуулагдсан",
    "Cannot copy" : "Хуулагдаагүй",
    "Copy link" : "Холбоос хуулах",
    "Download" : "Татаж авах",
    "Share with users or groups" : "Бусдад түгээх",
    "can edit" : "засаж чадна",
    "Cancel" : "болиулах",
    "Add" : "нэмэх",
    "First name" : "Нэр",
    "Last name" : "Овог",
    "Display name" : "Харагдах нэр",
    "Last modified" : "Сүүлд өөрчилсөн",
    "Save" : "Хадгалах",
    "Close" : "Хаах",
    "Folder" : "Folder",
    "New folder" : "Шинэ хавтас",
    "Create" : "Үүсгэх",
    "Invalid image" : "буруу зураг",
    "Upload a new picture" : "Шинэ зураг оруулах",
    "Choose from Files" : "Файлаас сонгох",
    "Download picture" : "Зураг татаж авах",
    "Delete picture" : "Зураг устгах",
    "Address book" : "Хаягийн бүртгэл",
    "Name" : "Нэр",
    "Title" : "Цол/Албан тушаал",
    "Select address book" : "Хаягийн бүртгэл сонгох",
    "Move" : "Move",
    "Groups" : "Багууд",
    "No results" : "Үр дүн байхгүй",
    "Pending" : "Хүлээгдэж байгаа",
    "None" : "юу ч үгүй",
    "Member" : "Гишүүн",
    "Add member" : "Гишүүн нэмэх",
    "New contact" : "Шинэ харилцагч",
    "Import" : "Импорт",
    "Not grouped" : "Багт ороогүй",
    "User" : "Хэрэглэгч",
    "Group" : "Бүлэг",
    "Email" : "Цахим шуудан",
    "Moderator" : "Шалгагч",
    "Admin" : "Админ",
    "Owner" : "Эзэмшигч",
    "Privacy" : "Хувийн нууц",
    "Detailed name" : "Дэлгэрэнгүй нэр",
    "Additional names" : "Нэмэлт нэрүүд",
    "Nickname" : "Товч нэр",
    "Notes" : "Тэмдэглэл",
    "Website" : "Цахим хуудас",
    "Location" : "Байршил",
    "Home" : "Гэр",
    "Work" : "Ажил",
    "Other" : "Бусад",
    "Address" : "Хаяг",
    "Post office box" : "Шуудангийн хайрцаг",
    "City" : "Хот",
    "State or province" : "Аймаг",
    "Postal code" : "Шуудангийн код",
    "Country" : "Улс",
    "Birthday" : "Төрсөн өдөр",
    "Date of death" : "Нас барсан огноо",
    "Phone" : "Утас",
    "Mobile" : "Гар утас",
    "Fax" : "Факс",
    "Fax home" : "Гэрийн факс",
    "Fax work" : "Ажлын факс",
    "Social network" : "Олон нийтийн сүлжээ",
    "Child" : "хүүхэд",
    "Mother" : "эх",
    "Father" : "эцэг",
    "Parent" : "эцэг эх",
    "Brother" : "ах",
    "Sister" : "эгч",
    "Relative" : "Хамаарал",
    "Friend" : "Найз",
    "Co-worker" : "Хамтран ажиллагч",
    "Gender" : "Хүйс",
    "Female" : "Эмэгтэй",
    "Male" : "Эрэгтэй",
    "Unknown" : "Үл танигдах зүйл",
    "Time zone" : "Цагийн бүс",
    "Loading …" : "Уншиж байна..."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-contacts-8.3.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/contacts/l10n/mn.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "Дэлгэрэнгүй",
    "All contacts" : "Бүх харилцагчид",
    "Contacts" : "Харилцагчид",
    "Copy to full name" : "Бүтэн нэр хуулах",
    "General" : "Ерөнхий",
    "Rename" : "Нэр солих",
    "Delete" : "Устгах",
    "Copied" : "Хуулагдсан",
    "Cannot copy" : "Хуулагдаагүй",
    "Copy link" : "Холбоос хуулах",
    "Download" : "Татаж авах",
    "Share with users or groups" : "Бусдад түгээх",
    "Cancel" : "болиулах",
    "Add" : "нэмэх",
    "First name" : "Нэр",
    "Last name" : "Овог",
    "Display name" : "Харагдах нэр",
    "Last modified" : "Сүүлд өөрчилсөн",
    "Save" : "Хадгалах",
    "Close" : "Хаах",
    "Folder" : "Folder",
    "New folder" : "Шинэ хавтас",
    "Create" : "Үүсгэх",
    "Invalid image" : "буруу зураг",
    "Upload a new picture" : "Шинэ зураг оруулах",
    "Choose from Files" : "Файлаас сонгох",
    "Download picture" : "Зураг татаж авах",
    "Delete picture" : "Зураг устгах",
    "Address book" : "Хаягийн бүртгэл",
    "Name" : "Нэр",
    "Title" : "Цол/Албан тушаал",
    "Select address book" : "Хаягийн бүртгэл сонгох",
    "Move" : "Move",
    "Groups" : "Багууд",
    "No results" : "Үр дүн байхгүй",
    "Pending" : "Хүлээгдэж байгаа",
    "None" : "юу ч үгүй",
    "Member" : "Гишүүн",
    "Add member" : "Гишүүн нэмэх",
    "New contact" : "Шинэ харилцагч",
    "Import" : "Импорт",
    "Not grouped" : "Багт ороогүй",
    "User" : "Хэрэглэгч",
    "Group" : "Бүлэг",
    "Email" : "Цахим шуудан",
    "Moderator" : "Шалгагч",
    "Admin" : "Админ",
    "Owner" : "Эзэмшигч",
    "Privacy" : "Хувийн нууц",
    "Detailed name" : "Дэлгэрэнгүй нэр",
    "Additional names" : "Нэмэлт нэрүүд",
    "Nickname" : "Товч нэр",
    "Notes" : "Тэмдэглэл",
    "Website" : "Цахим хуудас",
    "Location" : "Байршил",
    "Home" : "Гэр",
    "Work" : "Ажил",
    "Other" : "Бусад",
    "Address" : "Хаяг",
    "Post office box" : "Шуудангийн хайрцаг",
    "City" : "Хот",
    "State or province" : "Аймаг",
    "Postal code" : "Шуудангийн код",
    "Country" : "Улс",
    "Birthday" : "Төрсөн өдөр",
    "Date of death" : "Нас барсан огноо",
    "Phone" : "Утас",
    "Mobile" : "Гар утас",
    "Fax" : "Факс",
    "Fax home" : "Гэрийн факс",
    "Fax work" : "Ажлын факс",
    "Social network" : "Олон нийтийн сүлжээ",
    "Child" : "хүүхэд",
    "Mother" : "эх",
    "Father" : "эцэг",
    "Parent" : "эцэг эх",
    "Brother" : "ах",
    "Sister" : "эгч",
    "Relative" : "Хамаарал",
    "Friend" : "Найз",
    "Co-worker" : "Хамтран ажиллагч",
    "Gender" : "Хүйс",
    "Female" : "Эмэгтэй",
    "Male" : "Эрэгтэй",
    "Unknown" : "Үл танигдах зүйл",
    "Time zone" : "Цагийн бүс",
    "Loading …" : "Уншиж байна...",
    "can edit" : "засаж чадна"
},
"nplurals=2; plural=(n != 1);");
